@@ -507,7 +507,7 @@ GnomeUIInfo gamemenu[] = {
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_SCORES_ITEM(top_ten, NULL),
 	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_MENU_EXIT_ITEM(quit_game, NULL),
+	GNOMEUIINFO_MENU_QUIT_ITEM(quit_game, NULL),
 	GNOMEUIINFO_END
 };
 
@@ -517,7 +517,7 @@ GnomeUIInfo settingsmenu[] = {
 };
 
 GnomeUIInfo helpmenu[] = {
-        GNOMEUIINFO_HELP("gnomine"),
+        GNOMEUIINFO_HELP("gnome-mines"),
 	GNOMEUIINFO_MENU_ABOUT_ITEM(about, NULL),
 	GNOMEUIINFO_END
 };
@@ -615,7 +615,7 @@ main (int argc, char *argv[])
 			LIBGNOMEUI_MODULE,
 			argc, argv,
 			GNOME_PARAM_POPT_TABLE, options,
-			NULL);
+			GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
 
 	/* Get the default GConfClient */
 	conf_client = gconf_client_get_default ();
